import React, { HTMLAttributes } from "react";
import { ColorPickerSliderProps } from "@react-ui-types/colorpicker";
import { SliderState } from "@react-ui-stately/colorpicker";
import { SliderThumbProps } from "@react-ui-types/slider";
interface SliderAria {
    /** Props for the label element. */
    labelProps: HTMLAttributes<HTMLElement>;
    /** Props for the root element of the slider component; groups slider inputs. */
    containerProps: HTMLAttributes<HTMLElement>;
    /** Props for the track element. */
    trackProps: HTMLAttributes<HTMLElement>;
}
/**
 * Provides behavior and accessibility for a slider component.
 *
 * @param props Props for the slider.
 * @param state State for the slider, as returned by `useSliderState`.
 * @param trackRef Ref for the "track" element.  The width of this element provides the "length"
 * of the track -- the span of one dimensional space that the slider thumb can be.  It also
 * accepts click and drag motions, so that the closest thumb will follow clicks and drags on
 * the track.
 */
export function useSlider(props: ColorPickerSliderProps, state: SliderState, trackRef: React.RefObject<HTMLElement>): SliderAria;
interface SliderThumbAria {
    /** Props for the range input. */
    inputProps: HTMLAttributes<HTMLElement>;
    /** Props for the root thumb element; handles the dragging motion. */
    thumbProps: HTMLAttributes<HTMLElement>;
    /** Props for the label element for this thumb. */
    labelProps: HTMLAttributes<HTMLElement>;
}
interface SliderThumbOptions extends SliderThumbProps {
    trackRef: React.RefObject<HTMLElement>;
    inputRef: React.RefObject<HTMLInputElement>;
}
/**
 * Provides behavior and accessibility for a thumb of a slider component.
 *
 * @param opts Options for this Slider thumb.
 * @param state Slider state, created via `useSliderState`.
 */
export function useSVSlider(opts: SliderThumbOptions, state: SliderState): SliderThumbAria;
export function useAlphaSlider(): {};

//# sourceMappingURL=types.d.ts.map
